pub const unsafe fn get_bootinfo() -> &'static BootInfoExpand description
Get the bootinfo.
The BootInfo is pre-copied & fixed at the dedicated constant physical address 0x10000 by UEFI boot stage, never modified nor released in kernel lifetime.
Safety
Caller must ensure before invoking:
- Address
0x10000is allocated & filled with valid initialized BootInfo; - This range is reserved, never overwritten/freed by kernel/UEFI;
- No mutable aliasing exists for this memory region.
Note
Once the kernel do remapping, i suggest that map that region as PRESENT,
no WRITABLE.
Returns
&'static BootInfo: immutable static reference to the pre-filled BootInfo