Module header

Module header 

The definition of proka-kernel header.

This module will help you to create a header, and all you need to do is put it into the head of the kernel file.

Structs

Header