Module memory

Module memory 

The generic memory module, which provides memory info to kernel, so that kernel can know the memory structure easily.

Structs

MemoryEntry
The memory entry.
MemoryMap
The generic Memory Map, which can contains 128 memory map entries.

Enums

MemoryType
The memory type.