BootInfo

Struct BootInfo 

pub struct BootInfo { /* private fields */ }
This struct is the boot information struct, which provides the basic information, memory map, and so on.

Implementations

Source

impl BootInfo

pub const fn boot_mode(&self) -> &BootMode

Get the boot mode.

pub const fn framebuffer(&self) -> &Framebuffer

Get the framebuffer info.

pub const fn memory(&self) -> &MemoryMap

Get the memory map.

pub const fn acpi(&self) -> u64

Get the ACPI RSDP’s address.