Crate proka_bootloader

Crate proka_bootloader 

This crate provides the struct, enums about the Proka bootloader, including the boot information, and so on.

About proka bootloader

Well, this bootloader is for Proka Kernel, which will obey its standard. For more information, see .

Modules

memory
The generic memory module, which provides memory info to kernel, so that kernel can know the memory structure easily.
output
The output module, which provides framebuffer info and its utilities.

Structs

BootInfo
This struct is the boot information struct, which provides the basic information, memory map, and so on.

Enums

BootMode
This is the boot mode, only support 2 modes, which are legacy(BIOS) and UEFI.

Functions

get_bootinfo
Get the bootinfo.