The generic memory module, which provides memory info to kernel, so that kernel can know the memory structure easily.
Structs
- Memory
Entry - The memory entry.
- Memory
Map - The generic Memory Map, which can contains 128 memory map entries.
Enums
- Memory
Type - The memory type.