pub struct BootInfo { /* private fields */ }Expand description
This struct is the boot information struct, which provides the basic information, memory map, and so on.
Implementations
Sourceimpl BootInfo
impl BootInfo
Sourcepub unsafe fn put_addr(self, address: u64)
pub unsafe fn put_addr(self, address: u64)
Put the boot information to a fixed address
Safety
This is unsafe because we need to operate the pointer.
This function is for loader only.
Sourcepub unsafe fn load(address: u64) -> Self
pub unsafe fn load(address: u64) -> Self
Load the boot infomation from an address.
Safety
This is unsafe because we need to read from a pointer.
Sourcepub const fn framebuffer(&self) -> &Framebuffer
pub const fn framebuffer(&self) -> &Framebuffer
Get the framebuffer info.